@@ -64,10 +64,14 @@
 #define PATH_SYMLINK_DCONF_LOCK  AUTHSELECT_DCONF_DIR  "/locks/" AUTHSELECT_DCONF_FILE
 
 /* Path to profile directories. */
-#define DIR_DEFAULT_PROFILES AUTHSELECT_PROFILE_DIR
-#define DIR_VENDOR_PROFILES  AUTHSELECT_VENDOR_DIR
+#define DIR_DEFAULT_PROFILES AUTHSELECT_PROFILE_DIR"/default"
+#define DIR_VENDOR_PROFILES  AUTHSELECT_PROFILE_DIR"/vendor"
 #define DIR_CUSTOM_PROFILES  AUTHSELECT_CUSTOM_DIR
 
+/* Checksum file paths. */
+#define PATH_CHECKSUM_ORIG  AUTHSELECT_PROFILE_DIR"/checksum"
+#define PATH_CHECKSUM_COPY  AUTHSELECT_STATE_DIR"/checksum"
+
 /* Structure to hold path and content of generated system files.
  * @see GENERATED_FILES, GENERATED_FILES_PATHS */
 struct authselect_generated {
